@@ -85,8 +85,8 @@ if (suppressPackageStartupMessages(require(nlme, quietly = TRUE))) {
   })
 
   test_that("glance includes deviance iff method='ML'", {
-    expect(!("deviance" %in% names(glance(lmm0))))
-    expect("deviance" %in% names(glance(lmm0ML)))
+    expect(!("deviance" %in% names(glance(lmm0))),"deviance should not be in glance()")
+    expect("deviance" %in% names(glance(lmm0ML)),"deviance should be in glance()")
   })
 
   ## FIXME: weak tests - only shows that no error occurs and
@@ -147,5 +147,17 @@ if (suppressPackageStartupMessages(require(nlme, quietly = TRUE))) {
                  c("term","estimate","std.error","statistic","p.value",
                    "conf.low","conf.high"))
     
-  })      
+  })    
+
+  test_that("basic gls augment with & without data", {
+    au <- augment(gls1)
+    expect_is(au, 'data.frame')
+    expect_equal(nrow(au), nrow(Ovary))
+    expect_true(all(c(".fitted", ".resid") %in% names(au)))
+
+    au <- augment(gls1, data = Ovary)
+    expect_is(au, 'data.frame')
+    expect_equal(nrow(au), nrow(Ovary))
+    expect_true(all(c(".fitted", ".resid") %in% names(au)))
+  })  
 }
